.. AstraGeek documentation master file, created by
   sphinx-quickstart on Sun Feb 15 12:39:35 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

AstraGeek Sky Chart Tools
==========================

Software for building star maps and sky charts, developed for the
`AstraGeek <https://astrageek.ru/>`_ astronomy online school.

- Build classic sky charts and star maps via the `web interface <https://skychart.astrageek.ru/>`_
- Use the ``astrageek`` CLI to generate maps locally from the command line
- Educational astronomy videos: `astrageek.ru <https://astrageek.ru/>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents

   installation
   quickstart
   cli